@@ -54,32 +54,32 @@ fn main() -> Result<(), Box<dyn Error>> {
             )))
         .arg(Arg::new("INPUT_PATH")
             .required(true)
-            .help("Assigns an image for generating favicons. It should be a path of a file")
+            .help("Assign an image for generating favicons. It should be a path of a file")
             .takes_value(true)
             .display_order(0)
         )
         .arg(Arg::new("OUTPUT_PATH")
             .required(true)
-            .help("Assigns a destination of your generated files. It should be a path of a directory")
+            .help("Assign a destination of your generated files. It should be a path of a directory")
             .takes_value(true)
             .display_order(1)
         )
         .arg(Arg::new("OVERWRITE")
             .long("overwrite")
             .short('y')
-            .help("Overwrites exiting files without asking")
+            .help("Overwrite exiting files without asking")
             .display_order(0)
         )
         .arg(Arg::new("POTRACE_PATH")
             .long("potrace-path")
-            .help("Specifies the path of your potrace executable binary file")
+            .help("Specify the path of your potrace executable binary file")
             .takes_value(true)
             .default_value(DEFAULT_POTRACE_PATH)
             .display_order(1)
         )
         .arg(Arg::new("PATH_PREFIX")
             .long("path-prefix")
-            .help("Specifies the path prefix of your favicon files")
+            .help("Specify the path prefix of your favicon files")
             .takes_value(true)
             .default_value(DEFAULT_PATH_PREFIX)
             .display_order(2)
@@ -94,51 +94,51 @@ fn main() -> Result<(), Box<dyn Error>> {
         )
         .arg(Arg::new("NO_SHARPEN")
             .long("no-sharpen")
-            .help("Disables the automatic sharpening")
+            .help("Disable the automatic sharpening")
             .display_order(4)
         )
         .arg(Arg::new("APP_NAME").value_name("NAME")
             .long("app-name")
-            .help("Assigns a name for your web app")
+            .help("Assign a name for your web app")
             .takes_value(true)
             .display_order(10)
         )
         .arg(Arg::new("APP_SHORT_NAME").value_name("NAME")
             .long("app-short-name")
-            .help("Assigns a short name for your web app")
+            .help("Assign a short name for your web app")
             .takes_value(true)
             .display_order(11)
         )
         .arg(Arg::new("BACKGROUND_COLOR").value_name("HEX_COLOR")
             .long("background-color").visible_alias("background")
-            .help("Forces to assign a background color for all devices")
+            .help("Force to assign a background color for all devices")
             .takes_value(true)
             .display_order(12)
         )
         .arg(Arg::new("ANDROID_BACKGROUND_COLOR").value_name("HEX_COLOR")
             .long("android-background-color").visible_alias("android-background")
-            .help("Assigns a background color for Android devices")
+            .help("Assign a background color for Android devices")
             .takes_value(true)
             .default_value(DEFAULT_BACKGROUND_COLOR)
             .display_order(13)
         )
         .arg(Arg::new("IOS_BACKGROUND_COLOR").value_name("HEX_COLOR")
             .long("ios-background-color").visible_alias("ios-background")
-            .help("Assigns a background color for iOS devices")
+            .help("Assign a background color for iOS devices")
             .takes_value(true)
             .default_value(DEFAULT_BACKGROUND_COLOR)
             .display_order(14)
         )
         .arg(Arg::new("SAFARI_BACKGROUND_COLOR").value_name("HEX_COLOR")
             .long("safari-background-color").visible_alias("safari-background")
-            .help("Assigns a background color for Safari")
+            .help("Assign a background color for Safari")
             .takes_value(true)
             .default_value(DEFAULT_SAFARI_BACKGROUND_COLOR)
             .display_order(15)
         )
         .arg(Arg::new("WINDOWS_BACKGROUND_COLOR").value_name("HEX_COLOR")
             .long("windows-background-color").visible_alias("windows-background")
-            .help("Assigns a background color for Windows devices")
+            .help("Assign a background color for Windows devices")
             .takes_value(true)
             .default_value(DEFAULT_BACKGROUND_COLOR)
             .display_order(16)
